@@ -250,6 +250,10 @@ handle_atom (GOMSParserRecord *record, GSList *stack, const guint8 *data, GsfInp
 
 				/*				g_print ("%d: %x\n", indentation_level, fields);*/
 				if (fields & 0x000f) {
+					guint16 buflags = GSF_LE_GET_GUINT16 (data + i);
+					if (fields & 0x0001) {
+						g_object_set (para_attributes, "bullet_on", (gboolean) buflags & 0x1);
+					}
 					i += 2; /* Bullet Flags */
 				}
 				if (fields & 0x0080) {
@@ -410,7 +414,7 @@ handle_atom (GOMSParserRecord *record, GSList *stack, const guint8 *data, GsfInp
 					i += 2; /* Symbol */
 				if (fields & 0x00020000) {
 					pango_attributes = g_list_prepend (pango_attributes,
-									   pango_attr_size_new (GSF_LE_GET_GUINT16 (data + i) * PANGO_SCALE));
+									   pango_attr_size_new (GSF_LE_GET_GUINT16 (data + i) * PANGO_SCALE * 72 / 96)); /* Powerpoint fonts are specified in pixels at 96 dpi. */
 					i += 2;
 				}
 				if (fields & 0x00040000)
